@@ -209,7 +209,7 @@ class Environment(object):
 
 
     def _get_service_dict(self, image_name):
-        pre_service_dict = ENV_DICT_MAPPING[ClusterEnvironment.env_type]
+        pre_service_dict = ENV_DICT_MAPPING[self.env_type]
         aft_service_dict = []
         for service in pre_service_dict:
             service['image'] = image_name
@@ -227,22 +227,22 @@ class ClusterEnvironment(Environment):
 class DistributedEnvironment(Environment):
     env_type = "dst"
 
-    def __init__(self, env_name):
-        super(DistributedEnvironment, self).__init__(env_name)
+    def __init__(self, env_name, image_name):
+        super(DistributedEnvironment, self).__init__(env_name, image_name)
 
 
-class ShcEnvironment(Environment):
-    env_type = "shc"
-
-    def __init__(self, env_name):
-        super(ShcEnvironment, self).__init__(env_name)
+# class ShcEnvironment(Environment):
+# env_type = "shc"
+#
+# def __init__(self, env_name):
+#         super(ShcEnvironment, self).__init__(env_name)
 
 
 # CONSTANTS VARIABLES
 ENV_CLASS_MAPPING = {
     ClusterEnvironment.env_type: ClusterEnvironment,
     DistributedEnvironment.env_type: DistributedEnvironment,
-    ShcEnvironment.env_type: ShcEnvironment
+    # ShcEnvironment.env_type: ShcEnvironment
 }
 
 ENV_DICT_MAPPING = {
@@ -255,36 +255,37 @@ ENV_DICT_MAPPING = {
          'links': ['master'], u'name': 'indexer'}],
     DistributedEnvironment.env_type: [
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsh', 'ports': ['8000', '8089', '22'],
-         'links': ['master'], u'name': 'dsp'},
+         'links': ['dsp'], u'name': 'dsh'},
         {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'dsp', 'ports': ['8000', '8089', '22'],
          u'name': 'dsp'}],
-    ShcEnvironment.env_type: [
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
-         'links': ['master'], u'name': 'sh'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
-         u'name': 'master'},
-        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
-         'links': ['master'], u'name': 'indexer'}]
+    # ShcEnvironment.env_type: [
+    # {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
+    #      'links': ['master'], u'name': 'sh'},
+    #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
+    #      u'name': 'master'},
+    #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
+    #      'links': ['master'], u'name': 'indexer'}]
 }
 
 # if __name__ == "__main__":
-
-# testenv = Environment.get_environment_by_name('jacktestapi2')
-# testenv = Environment.get_environments()
-# print testenv[0].indexer.machines
-
-# myEnv = Environment.create_environment("cluster", "jacktestapi")
-# myEnv.bootstrap()
-
-# myEnv.get_service_names()
 #
-# myEnv.up()
-# myEnv.indexer.scale(2)
 #
-# print myEnv.indexer.machines[0].name
-# Environment.get_environments()
-# env = Environment.get_environment_by_name('jacktestapi_cluster')
-# print env.service_list
-# env.clean()
-# print 1
-
+# # testenv = Environment.get_environment_by_name('jacktestapi2')
+# # testenv = Environment.get_environments()
+# # print testenv[0].indexer.machines
+#
+#     myEnv = Environment.create_environment("dst", "dsttest")
+#     myEnv.bootstrap()
+#
+# # myEnv.get_service_names()
+# #
+# # myEnv.up()
+# # myEnv.indexer.scale(2)
+# #
+# # print myEnv.indexer.machines[0].name
+# # Environment.get_environments()
+# # env = Environment.get_environment_by_name('jacktestapi_cluster')
+# # print env.service_list
+# # env.clean()
+#     print 1
+#
